@@ -3,11 +3,11 @@ Tests for lss.py
 
 """
 import sys
-import os
 import unittest
 import numpy as np
 from numpy.testing import assert_allclose
 from quantecon.lss import LinearStateSpace
+from nose.tools import raises
 
 
 class TestLinearStateSpace(unittest.TestCase):
@@ -66,6 +66,15 @@ class TestLinearStateSpace(unittest.TestCase):
         assert_allclose(yval[0], expected_output)
 
 
+@raises(ValueError)
+def test_non_square_A():
+    A = np.zeros((1, 2))
+    C = np.zeros((1, 1))
+    G = np.zeros((1, 1))
+
+    LinearStateSpace(A, C, G)
+
+
 if __name__ == '__main__':
     suite = unittest.TestLoader().loadTestsFromTestCase(TestLinearStateSpace)
     unittest.TextTestRunner(verbosity=2, stream=sys.stderr).run(suite)
